==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Main/ThreadList/ThreadView/ThreadView.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System.Collections.Generic;
using System.Text;
using System;
using System.IO;
using System.Drawing.Imaging;
using System.Drawing;
using mshtml;
using System.Threading;
using MecInfoDll;

namespace nispi
{
    class ThreadView:ThreadViewCommon
    {
        public ThreadView():base()
        {
            this.threadViewControls = new ThreadListControls(this as ThreadViewCommon);

            //^uRg[ɃZbg
            Const.form.threadListTabControlParts.AddControl(this.threadViewControls.tabPageExParts);

            datUrl = null;

            shiori = new Shiori(this.threadViewControls.browserParts);
        }
        public override void dispoose()
        {
            /* bN */
            //if (this.ageonMutex.WaitOne() == false)
            //{
            //    this.ageonMutex.ReleaseMutex();
            //    return;
            //}

            try
            {
                this.ageonMutex.Terminate();

                int selectedIndex = Const.form.threadListTabControlParts.SelectedIndex;

                //SelectTabIndex(selectedIndex);
                Const.form.threadListTabControlParts.SuspendLayout();

                //SelectTabIndexFirst(selectedIndex);

                Const.form.threadListTabControlParts.ControlsRemove(threadViewControls.tabPageExParts);

                this.threadViewControls.RemoveAllControls();

                MainFormConst.threadListTabMain.RemoveView((ThreadViewCommon)this);

                SelectTabIndex(selectedIndex);

                Const.form.threadListTabControlParts.ResumeLayout();
            }
            catch { ;}

            /* bNJ */
            //this.ageonMutex.ReleaseMutex();

            //}WbNR[h
            //Const.form.mainForm.Size = new Size(Const.form.mainForm.Size.Width - 1, Const.form.mainForm.Size.Height - 1);
            //Const.form.mainForm.Size = new Size(Const.form.mainForm.Size.Width + 1, Const.form.mainForm.Size.Height + 1);
        }

        public override void dispooseAll()
        {
            /* bN */
            //if (this.ageonMutex.WaitOne() == false)
            //{
            //    this.ageonMutex.ReleaseMutex();
            //    return;
            //}
            try
            {
                this.ageonMutex.Terminate();

                //Const.form.threadListTabControlParts.ControlsRemove(threadViewControls.tabPageExParts);//.RemoveAllCtrl();//

                this.threadViewControls.RemoveAllControls();

                MainFormConst.threadListTabMain.RemoveView((ThreadViewCommon)this);
            }
            catch { ;}
            SelectTabIndex(1);
            SelectTabIndexFirst(0);
            /* bNJ */
            //this.ageonMutex.ReleaseMutex();
        }

        public void SelectTabIndexFirst(int selectIndex)
        {
            try
            {
                Const.form.threadListTabControlParts.SelectedIndex = 0;
            }
            catch { ;}
        }

        public void SelectTabIndex(int selectIndex)
        {
            try
            {
                if (selectIndex >= 0)
                {
                    /*if (selectIndex == 0)
                        Const.form.threadListTabControlParts.SelectedIndex = 0;
                    else if (selectIndex == 1)
                        Const.form.threadListTabControlParts.SelectedIndex = 1;
                    else if (selectIndex == 2)
                        Const.form.threadListTabControlParts.SelectedIndex = 2;
                    else if (selectIndex == 3)
                        Const.form.threadListTabControlParts.SelectedIndex = 2;
                    //ԉE̎ɂ̓}CiXP
                    else */if (selectIndex == Const.form.threadListTabControlParts.Count)
                        Const.form.threadListTabControlParts.SelectedIndex = selectIndex - 1;
                    //ȊOł́AȎIĂ^uI
                    else
                        Const.form.threadListTabControlParts.SelectedIndex = selectIndex;

                    while (Const.form.threadListTabControlParts.control.SelectedTab.Text.Length == 0)
                    {
                        if (Const.form.threadListTabControlParts.SelectedIndex < 1)
                            break;
                        Const.form.threadListTabControlParts.SelectedIndex -= 1;
                    }
                    

                }
            }
            catch { ;}
        }

        public override void write(DatInfo dat)
        {
            try
            {
                ReWriteToBrowser(dat, new Point(0,0));
            }
            catch (System.Exception ex)
            {
                Const.debugForm.OutPutDebug("ThreadList", ex); ;
            }

            //ĕ`
            MainFormConst.boardListTabMain.view_list[Const.form.boardListTabControlParts.SelectedIndex].boardListControls.listViewParts.Invalidate();
        }

        public override void ReWrite(DatInfo dat)
        {
            Point scrollpos = new Point(0,0);
            try
            {
                Const.form.mainForm.Invoke((Action)(() => scrollpos = this.threadViewControls.browserParts.GetScrollRectangle()));
                Thread.Sleep(1);
            }
            catch
            {
                Thread.Sleep(1);
            }
            try
            {
                ReWriteToBrowser(dat, scrollpos);
            }
            catch (System.Exception ex)
            {
                Const.debugForm.OutPutDebug("ThreadList", ex);
            }
        }
    }
}

==> AgeOn2.4_source.zip: AgeOn2.4_source/nispi/Controls/Main/ThreadList/ThreadView/ThreadView.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System.Collections.Generic;
using System.Text;
using System;
using System.IO;
using System.Drawing.Imaging;
using System.Drawing;
using mshtml;
using System.Threading;
using MecInfoDll;

namespace nispi
{
    class ThreadView:ThreadViewCommon
    {
        public ThreadView():base()
        {
            this.threadViewControls = new ThreadListControls(this as ThreadViewCommon);

            //^uRg[ɃZbg
            Const.form.threadListTabControlParts.AddControl(this.threadViewControls.tabPageExParts);

            datUrl = null;

            shiori = new Shiori(this.threadViewControls.browserParts);
        }
        public override void dispoose()
        {
            /* bN */
            //if (this.ageonMutex.WaitOne() == false)
            //{
            //    this.ageonMutex.ReleaseMutex();
            //    return;
            //}

            try
            {
                
                this.datUrl = "";
                this.threadName = "";

                this.ageonMutex.Terminate();

                int selectedIndex = Const.form.threadListTabControlParts.SelectedIndex;

                Const.form.threadListTabControlParts.SuspendLayout();

                this.threadViewControls.RemoveAllControls();

                MainFormConst.threadListTabMain.RemoveView((ThreadViewCommon)this);

                SelectTabIndex(selectedIndex);

                Const.form.threadListTabControlParts.ResumeLayout();
            }
            catch { ;}

            /* bNJ */
           // this.ageonMutex.ReleaseMutex();
        }

        public override void dispooseAll()
        {
            /* bN */
            //if (this.ageonMutex.WaitOne() == false)
            //{
            //    this.ageonMutex.ReleaseMutex();
            //    return;
            //}
            try
            {
                this.datUrl = "";
                this.threadName = "";

                this.ageonMutex.Terminate();

                this.threadViewControls.RemoveAllControls();

                MainFormConst.threadListTabMain.RemoveView((ThreadViewCommon)this);
            }
            catch { ;}
            //SelectTabIndex(1);
            //SelectTabIndexFirst(0);
            /* bNJ */
            //this.ageonMutex.ReleaseMutex();
        }

        public void SelectTabIndexFirst(int selectIndex)
        {
            //try
            //{
            Const.form.threadListTabControlParts.SelectedIndex = 0;
            //}
            //catch { ;}
        }

        public void SelectTabIndex(int selectIndex)
        {
            //try
            //{
            if (selectIndex >= 0)
            {
                /*if (selectIndex == 0)
                    Const.form.threadListTabControlParts.SelectedIndex = 0;
                else if (selectIndex == 1)
                    Const.form.threadListTabControlParts.SelectedIndex = 1;
                else if (selectIndex == 2)
                    Const.form.threadListTabControlParts.SelectedIndex = 2;
                else if (selectIndex == 3)
                    Const.form.threadListTabControlParts.SelectedIndex = 2;
                //ԉE̎ɂ̓}CiXP
                else */
                if (selectIndex == Const.form.threadListTabControlParts.Count)
                    Const.form.threadListTabControlParts.SelectedIndex = selectIndex - 1;
                //ȊOł́AȎIĂ^uI
                else
                {
                    try
                    {
                        Const.form.threadListTabControlParts.SelectedIndex = selectIndex + 1;
                    }
                    catch { ;}
                    Const.form.threadListTabControlParts.SelectedIndex = selectIndex;
                }
                while (Const.form.threadListTabControlParts.control.SelectedTab.Text.Length == 0)
                {
                    if (Const.form.threadListTabControlParts.SelectedIndex < 1)
                        break;
                    Const.form.threadListTabControlParts.SelectedIndex -= 1;
                }


            }
            //}
            //catch { ;}
        }

        public override void write(DatInfo dat)
        {
            try
            {
                ReWriteToBrowser(dat, new Point(0,0));
            }
            catch (System.Exception ex)
            {
                //Const.debugForm.OutPutDebug("ThreadList", ex); ;
            }

            //ĕ`
            MainFormConst.boardListTabMain.view_list[Const.form.boardListTabControlParts.SelectedIndex].boardListControls.listViewParts.Invalidate();
        }

        public override void ReWrite(DatInfo dat)
        {
            Point scrollpos = new Point(0,0);
            try
            {
                Const.form.mainForm.Invoke((Action)(() => scrollpos = this.threadViewControls.browserParts.GetScrollRectangle()));
                Thread.Sleep(1);
            }
            catch
            {
                Thread.Sleep(1);
            }
            try
            {
                ReWriteToBrowser(dat, scrollpos);
            }
            catch (System.Exception ex)
            {
                //Const.debugForm.OutPutDebug("ThreadList", ex);
            }
        }
    }
}
